@@ -1,8 +1,8 @@
 -- --------------------------------------------------------
 -- SQL Commands to set up the pmadb as described in Documentation.html.
---
+-- 
 -- This file is meant for use with MySQL 5 and above!
---
+-- 
 -- This script expects the user pma to already be existing. If we would put a
 -- line here to create him too many users might just use this script and end
 -- up with having the same password for the controluser.
@@ -11,7 +11,6 @@
 --                                                  
 -- Please don't forget to set up the tablenames in config.inc.php                                 
 -- 
--- $Id$
 
 -- --------------------------------------------------------
 
@@ -80,7 +79,7 @@ CREATE TABLE IF NOT EXISTS `pma_history` (
   `username` varchar(64) NOT NULL default '',
   `db` varchar(64) NOT NULL default '',
   `table` varchar(64) NOT NULL default '',
-  `timevalue` timestamp(14) NOT NULL,
+  `timevalue` timestamp NOT NULL,
   `sqlquery` text NOT NULL,
   PRIMARY KEY  (`id`),
   KEY `username` (`username`,`db`,`table`,`timevalue`)
@@ -173,9 +172,11 @@ CREATE TABLE IF NOT EXISTS `pma_designer_coords` (
   ENGINE=MyISAM COMMENT='Table coordinates for Designer'
   DEFAULT CHARACTER SET utf8 COLLATE utf8_bin;
 
---
+-- --------------------------------------------------------
+
+-- 
 -- Table structure for table `pma_tracking`
---
+-- 
 
 CREATE TABLE IF NOT EXISTS `pma_tracking` (
   `db_name` varchar(64) collate utf8_bin NOT NULL,
@@ -185,8 +186,23 @@ CREATE TABLE IF NOT EXISTS `pma_tracking` (
   `date_updated` datetime NOT NULL,
   `schema_snapshot` text collate utf8_bin NOT NULL,
   `schema_sql` text collate utf8_bin,
-  `data_sql` text collate utf8_bin,
+  `data_sql` longtext collate utf8_bin,
   `tracking` set('UPDATE','REPLACE','INSERT','DELETE','TRUNCATE','CREATE DATABASE','ALTER DATABASE','DROP DATABASE','CREATE TABLE','ALTER TABLE','RENAME TABLE','DROP TABLE','CREATE INDEX','DROP INDEX','CREATE VIEW','ALTER VIEW','DROP VIEW') collate utf8_bin default NULL,
   `tracking_active` int(1) unsigned NOT NULL default '1',
   PRIMARY KEY  (`db_name`,`table_name`,`version`)
 ) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_bin ROW_FORMAT=COMPACT;
+
+-- --------------------------------------------------------
+
+--
+-- Table structure for table `pma_userconfig`
+--
+
+CREATE TABLE IF NOT EXISTS `pma_userconfig` (
+  `username` varchar(64) NOT NULL,
+  `timevalue` timestamp NOT NULL,
+  `config_data` text NOT NULL,
+  PRIMARY KEY  (`username`)
+)
+  ENGINE=MyISAM COMMENT='User preferences storage for phpMyAdmin'
+  DEFAULT CHARACTER SET utf8 COLLATE utf8_bin;
