@@ -3,16 +3,19 @@
 /**
  * Simple wrapper just to enable error reporting and include config
  *
- * @version $Id$
  * @package phpMyAdmin
  */
 
+require './libraries/vendor_config.php';
+
 echo "Starting to parse config file...\n";
 
 error_reporting(E_ALL);
 /**
  * Read config file.
  */
-require './config.inc.php';
+if (is_readable(CONFIG_FILE)) {
+    require CONFIG_FILE;
+}
 
 ?>
