@@ -2,14 +2,11 @@
 /* vim: set expandtab sw=4 ts=4 sts=4: */
 /**
  *
- * @author Alexander Rutkowski
- * @version $Id$
  * @package phpMyAdmin
  */
 
 // Run common work
 require_once './libraries/common.inc.php';
-require_once './libraries/Table.class.php';
 
 define('TABLE_MAY_BE_ABSENT', true);
 require './libraries/tbl_common.php';
@@ -17,9 +14,6 @@ $url_query .= '&amp;goto=tbl_tracking.php&amp;back=tbl_tracking.php';
 $url_params['goto'] = 'tbl_tracking.php';;
 $url_params['back'] = 'tbl_tracking.php';
 
-// Get relation settings
-require_once './libraries/relation.lib.php';
-
 // Init vars for tracking report
 if (isset($_REQUEST['report']) || isset($_REQUEST['report_export'])) {
     $data = PMA_Tracker::getTrackedData($_REQUEST['db'], $_REQUEST['table'], $_REQUEST['version']);
@@ -56,14 +50,14 @@ if (isset($_REQUEST['report']) || isset($_REQUEST['report_export'])) {
 if (isset($_REQUEST['report_export'])) {
 
 /**
- * Filters tracking entries 
+ * Filters tracking entries
  *
- * @param   array   the entries to filter 
+ * @param   array   the entries to filter
  * @param   string  "from" date
  * @param   string  "to" date
- * @param   string  users 
+ * @param   string  users
  *
- * @return  array   filtered entries 
+ * @return  array   filtered entries
  *
  */
     function PMA_filter_tracking($data, $filter_ts_from, $filter_ts_to, $filter_users) {
@@ -72,7 +66,7 @@ if (isset($_REQUEST['report_export'])) {
         foreach( $data as $entry ) {
             $timestamp = strtotime($entry['date']);
 
-            if ($timestamp >= $filter_ts_from && $timestamp <= $filter_ts_to && 
+            if ($timestamp >= $filter_ts_from && $timestamp <= $filter_ts_to &&
               ( in_array('*', $filter_users) || in_array($entry['username'], $filter_users) ) ) {
                 $tmp_entries[] = array( 'id' => $id,
                                     'timestamp' => $timestamp,
@@ -112,12 +106,13 @@ if (isset($_REQUEST['report_export'])) {
 if (isset($_REQUEST['report_export']) && $_REQUEST['export_type'] == 'sqldumpfile') {
     @ini_set('url_rewriter.tags','');
 
-    $dump = "# " . sprintf($strTrackingReportForTable, htmlspecialchars($_REQUEST['table'])) . "\n" .
+    $dump = "# " . sprintf(__('Tracking report for table `%s`'), htmlspecialchars($_REQUEST['table'])) . "\n" .
             "# " . date('Y-m-d H:i:s') . "\n";
     foreach($entries as $entry) {
         $dump .= $entry['statement'];
     }
-    $filename = 'log_' . htmlspecialchars($_REQUEST['table']) . '.sql';
+    //$filename = 'log_' . str_replace(';', '', htmlspecialchars($_REQUEST['table'])) . '.sql';
+    $filename = PMA_sanitize_filename('log_' . $_REQUEST['table'] . '.sql');
     header('Content-Type: text/x-sql');
     header('Expires: ' . gmdate('D, d M Y H:i:s') . ' GMT');
     header('Content-Disposition: attachment; filename="' . $filename . '"');
@@ -185,7 +180,7 @@ if (isset($_REQUEST['submit_create_version'])) {
     $tracking_set = rtrim($tracking_set, ',');
 
     if (PMA_Tracker::createVersion($GLOBALS['db'], $GLOBALS['table'], $_REQUEST['version'], $tracking_set )) {
-        $msg = PMA_Message::success(sprintf($strTrackingVersionCreated, $_REQUEST['version'], $GLOBALS['db'], $GLOBALS['table']));
+        $msg = PMA_Message::success(sprintf(__('Version %s is created, tracking for %s.%s is activated.'), htmlspecialchars($_REQUEST['version']), htmlspecialchars($GLOBALS['db']), htmlspecialchars($GLOBALS['table'])));
         $msg->display();
     }
 }
@@ -193,7 +188,7 @@ if (isset($_REQUEST['submit_create_version'])) {
 // Deactivate tracking
 if (isset($_REQUEST['submit_deactivate_now'])) {
     if (PMA_Tracker::deactivateTracking($GLOBALS['db'], $GLOBALS['table'], $_REQUEST['version'])) {
-        $msg = PMA_Message::success(sprintf($strTrackingVersionDeactivated, $GLOBALS['db'], $GLOBALS['table'], $_REQUEST['version']));
+        $msg = PMA_Message::success(sprintf(__('Tracking for %s.%s , version %s is deactivated.'), htmlspecialchars($GLOBALS['db']), htmlspecialchars($GLOBALS['table']), htmlspecialchars($_REQUEST['version'])));
         $msg->display();
     }
 }
@@ -201,7 +196,7 @@ if (isset($_REQUEST['submit_deactivate_now'])) {
 // Activate tracking
 if (isset($_REQUEST['submit_activate_now'])) {
     if (PMA_Tracker::activateTracking($GLOBALS['db'], $GLOBALS['table'], $_REQUEST['version'])) {
-        $msg = PMA_Message::success(sprintf($strTrackingVersionActivated, $GLOBALS['db'], $GLOBALS['table'], $_REQUEST['version']));
+        $msg = PMA_Message::success(sprintf(__('Tracking for %s.%s , version %s is activated.'), htmlspecialchars($GLOBALS['db']), htmlspecialchars($GLOBALS['table']), htmlspecialchars($_REQUEST['version'])));
         $msg->display();
     }
 }
@@ -211,15 +206,15 @@ if (isset($_REQUEST['report_export']) && $_REQUEST['export_type'] == 'execution'
     foreach($entries as $entry) {
         $sql_result = PMA_DBI_query( "/*NOTRACK*/\n" . $entry['statement'] );
     }
-    $msg = PMA_Message::success($strTrackingSQLExecuted);
+    $msg = PMA_Message::success(__('SQL statements executed.'));
     $msg->display();
 }
 
 // Export as SQL dump
 if (isset($_REQUEST['report_export']) && $_REQUEST['export_type'] == 'sqldump')
 {
-    $new_query =    "# " . $strTrackingYouCanExecute . "\n" .
-                    "# " . $strTrackingCommentOut . "\n" .
+    $new_query =    "# " . __('You can execute the dump by creating and using a temporary database. Please ensure that you have the privileges to do so.') . "\n" .
+                    "# " . __('Comment out these two lines if you do not need them.') . "\n" .
                     "\n" .
                     "CREATE database IF NOT EXISTS pma_temp_db; \n" .
                     "USE pma_temp_db; \n" .
@@ -228,14 +223,13 @@ if (isset($_REQUEST['report_export']) && $_REQUEST['export_type'] == 'sqldump')
     foreach($entries as $entry) {
         $new_query .= $entry['statement'];
     }
-    $msg = PMA_Message::success($strTrackingSQLExported);
+    $msg = PMA_Message::success(__('SQL statements exported. Please copy the dump or execute it.'));
     $msg->display();
 
     $db_temp = $db;
     $table_temp = $table;
 
     $db = $table = '';
-    $GLOBALS['js_include'][] = 'functions.js';
     require_once './libraries/sql_query_form.lib.php';
 
     PMA_sqlQueryForm($new_query, 'sql');
@@ -249,7 +243,7 @@ if (isset($_REQUEST['report_export']) && $_REQUEST['export_type'] == 'sqldump')
  */
 if (isset($_REQUEST['snapshot'])) {
 ?>
-    <h3><?php echo $strTrackingStructureSnapshot;?>  [<a href="tbl_tracking.php?<?php echo $url_query;?>"><?php echo $strTrackingReportClose;?></a>]</h3>
+    <h3><?php echo __('Structure snapshot');?>  [<a href="tbl_tracking.php?<?php echo $url_query;?>"><?php echo __('Close');?></a>]</h3>
 <?php
     $data = PMA_Tracker::getTrackedData($_REQUEST['db'], $_REQUEST['table'], $_REQUEST['version']);
 
@@ -260,24 +254,24 @@ if (isset($_REQUEST['snapshot'])) {
         $drop_create_statements .= $data['ddlog'][1]['statement'];
     }
     // Print SQL code
-    PMA_showMessage(sprintf($strTrackingVersionSnapshotSQL, $_REQUEST['version']), $drop_create_statements);
+    PMA_showMessage(sprintf(__('Version %s snapshot (SQL code)'), htmlspecialchars($_REQUEST['version'])), $drop_create_statements);
 
     // Unserialize snapshot
     $temp = unserialize($data['schema_snapshot']);
     $columns = $temp['COLUMNS'];
     $indexes = $temp['INDEXES'];
 ?>
-    <h3><?php echo $strStructure;?></h3>
+    <h3><?php echo __('Structure');?></h3>
     <table id="tablestructure" class="data">
     <thead>
     <tr>
-        <th><?php echo $strField; ?></th>
-        <th><?php echo $strType; ?></th>
-        <th><?php echo $strCollation; ?></th>
-        <th><?php echo $strNull; ?></th>
-        <th><?php echo $strDefault; ?></th>
-        <th><?php echo $strExtra; ?></th>
-        <th><?php echo $strComment; ?></th>
+        <th><?php echo __('Column'); ?></th>
+        <th><?php echo __('Type'); ?></th>
+        <th><?php echo __('Collation'); ?></th>
+        <th><?php echo __('Null'); ?></th>
+        <th><?php echo __('Default'); ?></th>
+        <th><?php echo __('Extra'); ?></th>
+        <th><?php echo __('Comment'); ?></th>
     </tr>
     </thead>
     <tbody>
@@ -285,25 +279,25 @@ if (isset($_REQUEST['snapshot'])) {
     $style = 'odd';
     foreach($columns as $field_index => $field) {
 ?>
-        <tr class="<?php echo $style; ?>">
+        <tr class="noclick <?php echo $style; ?>">
             <?php
             if ($field['Key'] == 'PRI') {
-                echo '<td><b><u>' . $field['Field'] . '</u></b></td>' . "\n";
+                echo '<td><b><u>' . htmlspecialchars($field['Field']) . '</u></b></td>' . "\n";
             } else {
-                echo '<td><b>' . $field['Field'] . '</b></td>' . "\n";
+                echo '<td><b>' . htmlspecialchars($field['Field']) . '</b></td>' . "\n";
             }
             ?>
-            <td><?php echo $field['Type'];?></td>
-            <td><?php echo $field['Collation'];?></td>
-            <td><?php echo $field['Null'];?></td>
-            <td><?php echo $field['Default'];?></td>
-            <td><?php echo $field['Extra'];?></td>
-            <td><?php echo $field['Comment'];?></td>
+            <td><?php echo htmlspecialchars($field['Type']);?></td>
+            <td><?php echo htmlspecialchars($field['Collation']);?></td>
+            <td><?php echo htmlspecialchars($field['Null']);?></td>
+            <td><?php echo htmlspecialchars($field['Default']);?></td>
+            <td><?php echo htmlspecialchars($field['Extra']);?></td>
+            <td><?php echo htmlspecialchars($field['Comment']);?></td>
         </tr>
 <?php
             if ($style == 'even') {
-                $style = 'odd'; 
-            } else { 
+                $style = 'odd';
+            } else {
                 $style = 'even';
             }
     }
@@ -314,49 +308,49 @@ if (isset($_REQUEST['snapshot'])) {
 <?php
     if (count($indexes) > 0) {
 ?>
-        <h3><?php echo $strIndexes;?></h3>
+        <h3><?php echo __('Indexes');?></h3>
         <table id="tablestructure_indexes" class="data">
         <thead>
         <tr>
-            <th><?php echo $strKeyname;?></th>
-            <th><?php echo $strType;?></th>
-            <th><?php echo $strUnique;?></th>
-            <th><?php echo $strPacked;?></th>
-            <th><?php echo $strField;?></th>
-            <th><?php echo $strCardinality;?></th>
-            <th><?php echo $strCollation;?></th>
-            <th><?php echo $strNull;?></th>
-            <th><?php echo $strComment;?></th>
+            <th><?php echo __('Keyname');?></th>
+            <th><?php echo __('Type');?></th>
+            <th><?php echo __('Unique');?></th>
+            <th><?php echo __('Packed');?></th>
+            <th><?php echo __('Column');?></th>
+            <th><?php echo __('Cardinality');?></th>
+            <th><?php echo __('Collation');?></th>
+            <th><?php echo __('Null');?></th>
+            <th><?php echo __('Comment');?></th>
         </tr>
         <tbody>
 <?php
         $style = 'odd';
         foreach ($indexes as $indexes_index => $index) {
             if ($index['Non_unique'] == 0) {
-                $str_unique = $strYes;
+                $str_unique = __('Yes');
             } else {
-                $str_unique = $strNo;
+                $str_unique = __('No');
             }
             if ($index['Packed'] != '') {
-                $str_packed = $strYes;
+                $str_packed = __('Yes');
             } else {
-                $str_packed = $strNo;
+                $str_packed = __('No');
             }
 ?>
-            <tr class="<?php echo $style; ?>">
-                <td><b><?php echo $index['Key_name'];?></b></td>
-                <td><?php echo $index['Index_type'];?></td>
+            <tr class="noclick <?php echo $style; ?>">
+                <td><b><?php echo htmlspecialchars($index['Key_name']);?></b></td>
+                <td><?php echo htmlspecialchars($index['Index_type']);?></td>
                 <td><?php echo $str_unique;?></td>
                 <td><?php echo $str_packed;?></td>
-                <td><?php echo $index['Column_name'];?></td>
-                <td><?php echo $index['Cardinality'];?></td>
-                <td><?php echo $index['Collation'];?></td>
-                <td><?php echo $index['Null'];?></td>
-                <td><?php echo $index['Comment'];?></td>
+                <td><?php echo htmlspecialchars($index['Column_name']);?></td>
+                <td><?php echo htmlspecialchars($index['Cardinality']);?></td>
+                <td><?php echo htmlspecialchars($index['Collation']);?></td>
+                <td><?php echo htmlspecialchars($index['Null']);?></td>
+                <td><?php echo htmlspecialchars($index['Comment']);?></td>
             </tr>
 <?php
             if ($style == 'even') {
-                $style = 'odd'; 
+                $style = 'odd';
             } else {
                 $style = 'even';
             }
@@ -377,25 +371,25 @@ if (isset($_REQUEST['snapshot'])) {
  */
 if (isset($_REQUEST['report']) || isset($_REQUEST['report_export'])) {
     ?>
-    <h3><?php echo $strTrackingReport;?>  [<a href="tbl_tracking.php?<?php echo $url_query;?>"><?php echo $strTrackingReportClose;?></a>]</h3>
+    <h3><?php echo __('Tracking report');?>  [<a href="tbl_tracking.php?<?php echo $url_query;?>"><?php echo __('Close');?></a>]</h3>
 
-    <small><?php echo $strTrackingStatements . ' ' . $data['tracking']; ?></small><br/>
+    <small><?php echo __('Tracking statements') . ' ' . htmlspecialchars($data['tracking']); ?></small><br/>
     <br/>
 
-    <form method="post" action="tbl_tracking.php?<?php echo $url_query; ?>&amp;report=true&amp;version=<?php echo $_REQUEST['version'];?>">
+    <form method="post" action="tbl_tracking.php<?php echo PMA_generate_common_url($url_params + array('report' => 'true', 'version' => $_REQUEST['version'])); ?>">
     <?php
 
     $str1 = '<select name="logtype">' .
-            '<option value="schema"' . ($selection_schema ? ' selected="selected"' : '') . '>' . $strStrucOnly . '</option>' .
-            '<option value="data"' . ($selection_data ? ' selected="selected"' : ''). '>' . $strDataOnly . '</option>' .
-            '<option value="schema_and_data"' . ($selection_both ? ' selected="selected"' : '') . '>' . $strStrucData . '</option>' .
+            '<option value="schema"' . ($selection_schema ? ' selected="selected"' : '') . '>' . __('Structure only') . '</option>' .
+            '<option value="data"' . ($selection_data ? ' selected="selected"' : ''). '>' . __('Data only') . '</option>' .
+            '<option value="schema_and_data"' . ($selection_both ? ' selected="selected"' : '') . '>' . __('Structure and data') . '</option>' .
             '</select>';
-    $str2 = '<input type="text" name="date_from" value="' . $_REQUEST['date_from'] . '" size="19" />';
-    $str3 = '<input type="text" name="date_to" value="' . $_REQUEST['date_to'] . '" size="19" />';
-    $str4 = '<input type="text" name="users" value="' . $_REQUEST['users'] . '" />';
-    $str5 = '<input type="submit" name="list_report" value="' . $strGo . '" />';
+    $str2 = '<input type="text" name="date_from" value="' . htmlspecialchars($_REQUEST['date_from']) . '" size="19" />';
+    $str3 = '<input type="text" name="date_to" value="' . htmlspecialchars($_REQUEST['date_to']) . '" size="19" />';
+    $str4 = '<input type="text" name="users" value="' . htmlspecialchars($_REQUEST['users']) . '" />';
+    $str5 = '<input type="submit" name="list_report" value="' . __('Go') . '" />';
 
-    printf($strTrackingShowLogDateUsers, $str1, $str2, $str3, $str4, $str5);
+    printf(__('Show %s with dates from %s to %s by user %s %s'), $str1, $str2, $str3, $str4, $str5);
 
 
     /*
@@ -408,31 +402,34 @@ if (isset($_REQUEST['report']) || isset($_REQUEST['report_export'])) {
         <thead>
         <tr>
             <th width="18">#</th>
-            <th width="100"><?php echo $strTrackingDate;?></th>
-            <th width="60"><?php echo $strTrackingUsername;?></th>
-            <th><?php echo $strTrackingDataDefinitionStatement;?></th>
+            <th width="100"><?php echo __('Date');?></th>
+            <th width="60"><?php echo __('Username');?></th>
+            <th><?php echo __('Data definition statement');?></th>
         </tr>
         </thead>
         <tbody>
         <?php
         $style = 'odd';
         foreach ($data['ddlog'] as $entry) {
-            $parsed_sql = PMA_SQP_parse($entry['statement']);
-            $statement  = PMA_formatSql($parsed_sql);
+            if (strlen($entry['statement']) > $GLOBALS['cfg']['MaxCharactersInDisplayedSQL']) {
+                $statement = substr($entry['statement'], 0, $GLOBALS['cfg']['MaxCharactersInDisplayedSQL']) . '[...]';
+            } else {
+                $statement  = PMA_formatSql(PMA_SQP_parse($entry['statement']));
+            }
             $timestamp = strtotime($entry['date']);
 
-            if ($timestamp >= $filter_ts_from && $timestamp <= $filter_ts_to && 
+            if ($timestamp >= $filter_ts_from && $timestamp <= $filter_ts_to &&
               ( in_array('*', $filter_users) || in_array($entry['username'], $filter_users) ) ) {
         ?>
-                <tr class="<?php echo $style; ?>">
+                <tr class="noclick <?php echo $style; ?>">
                     <td><small><?php echo $i;?></small></td>
-                    <td><small><?php echo $entry['date'];?></small></td>
-                    <td><small><?php echo $entry['username']; ?></small></td>
+                    <td><small><?php echo htmlspecialchars($entry['date']);?></small></td>
+                    <td><small><?php echo htmlspecialchars($entry['username']); ?></small></td>
                     <td><?php echo $statement; ?></td>
                 </tr>
         <?php
                 if ($style == 'even') {
-                    $style = 'odd'; 
+                    $style = 'odd';
                 } else {
                     $style = 'even';
                 }
@@ -456,32 +453,35 @@ if (isset($_REQUEST['report']) || isset($_REQUEST['report_export'])) {
         <thead>
         <tr>
             <th width="18">#</th>
-            <th width="100"><?php echo $strTrackingDate;?></th>
-            <th width="60"><?php echo $strTrackingUsername;?></th>
-            <th><?php echo $strTrackingDataManipulationStatement;?></th>
+            <th width="100"><?php echo __('Date');?></th>
+            <th width="60"><?php echo __('Username');?></th>
+            <th><?php echo __('Data manipulation statement');?></th>
         </tr>
         </thead>
         <tbody>
         <?php
         $style = 'odd';
         foreach ($data['dmlog'] as $entry) {
-            $parsed_sql = PMA_SQP_parse($entry['statement']);
-            $statement  = PMA_formatSql($parsed_sql);
+            if (strlen($entry['statement']) > $GLOBALS['cfg']['MaxCharactersInDisplayedSQL']) {
+                $statement = substr($entry['statement'], 0, $GLOBALS['cfg']['MaxCharactersInDisplayedSQL']) . '[...]';
+            } else {
+                $statement  = PMA_formatSql(PMA_SQP_parse($entry['statement']));
+            }
             $timestamp = strtotime($entry['date']);
 
-            if ($timestamp >= $filter_ts_from && $timestamp <= $filter_ts_to && 
+            if ($timestamp >= $filter_ts_from && $timestamp <= $filter_ts_to &&
               ( in_array('*', $filter_users) || in_array($entry['username'], $filter_users) ) ) {
         ?>
-                <tr class="<?php echo $style; ?>">
+                <tr class="noclick <?php echo $style; ?>">
                     <td><small><?php echo $i; ?></small></td>
-                    <td><small><?php echo $entry['date']; ?></small></td>
-                    <td><small><?php echo $entry['username']; ?></small></td>
+                    <td><small><?php echo htmlspecialchars($entry['date']); ?></small></td>
+                    <td><small><?php echo htmlspecialchars($entry['username']); ?></small></td>
                     <td><?php echo $statement; ?></td>
                 </tr>
         <?php
                 if ($style == 'even') {
-                    $style = 'odd'; 
-                } else { 
+                    $style = 'odd';
+                } else {
                     $style = 'even';
                 }
                 $i++;
@@ -494,26 +494,26 @@ if (isset($_REQUEST['report']) || isset($_REQUEST['report_export'])) {
     }
     ?>
     </form>
-    <form method="post" action="tbl_tracking.php?<?php echo $url_query; ?>&amp;report=true&amp;version=<?php echo $_REQUEST['version'];?>">
+    <form method="post" action="tbl_tracking.php<?php echo PMA_generate_common_url($url_params + array('report' => 'true', 'version' => $_REQUEST['version'])); ?>">
     <?php
-    printf($strTrackingShowLogDateUsers, $str1, $str2, $str3, $str4, $str5);
+    printf(__('Show %s with dates from %s to %s by user %s %s'), $str1, $str2, $str3, $str4, $str5);
 
     $str_export1 =  '<select name="export_type">' .
-                    '<option value="sqldumpfile">' . $strTrackingSQLDumpFile . '</option>' .
-                    '<option value="sqldump">' . $strTrackingSQLDump . '</option>' .
-                    '<option value="execution" onclick="alert(\'' . $strTrackingSQLExecutionAlert .'\')">' . $strTrackingSQLExecution . '</option>' .
+                    '<option value="sqldumpfile">' . __('SQL dump (file download)') . '</option>' .
+                    '<option value="sqldump">' . __('SQL dump') . '</option>' .
+                    '<option value="execution" onclick="alert(\'' . PMA_escapeJsString(__('This option will replace your table and contained data.')) .'\')">' . __('SQL execution') . '</option>' .
                     '</select>';
 
-    $str_export2 = '<input type="submit" name="report_export" value="' . $strGo .'" />';
+    $str_export2 = '<input type="submit" name="report_export" value="' . __('Go') .'" />';
     ?>
     </form>
-    <form method="post" action="tbl_tracking.php?<?php echo $url_query; ?>&amp;report=true&amp;version=<?php echo $_REQUEST['version'];?>">
-    <input type="hidden" name="logtype" value="<?php echo $_REQUEST['logtype'];?>" />
-    <input type="hidden" name="date_from" value="<?php echo $_REQUEST['date_from'];?>" />
-    <input type="hidden" name="date_to" value="<?php echo $_REQUEST['date_to'];?>" />
-    <input type="hidden" name="users" value="<?php echo $_REQUEST['users'];?>" />
+    <form method="post" action="tbl_tracking.php<?php echo PMA_generate_common_url($url_params + array('report' => 'true', 'version' => $_REQUEST['version'])); ?>">
+    <input type="hidden" name="logtype" value="<?php echo htmlspecialchars($_REQUEST['logtype']);?>" />
+    <input type="hidden" name="date_from" value="<?php echo htmlspecialchars($_REQUEST['date_from']);?>" />
+    <input type="hidden" name="date_to" value="<?php echo htmlspecialchars($_REQUEST['date_to']);?>" />
+    <input type="hidden" name="users" value="<?php echo htmlspecialchars($_REQUEST['users']);?>" />
     <?php
-    echo "<br/>" . sprintf($strTrackingExportAs, $str_export1) . $str_export2 . "<br/>";
+    echo "<br/>" . sprintf(__('Export as %s'), $str_export1) . $str_export2 . "<br/>";
     ?>
     </form>
     <?php
@@ -540,9 +540,9 @@ if (PMA_DBI_num_rows($sql_result) > 0) {
     <?php
     while ($entries = PMA_DBI_fetch_array($sql_result)) {
         if (PMA_Tracker::isTracked($entries['db_name'], $entries['table_name'])) {
-            $status = ' (' . $strTrackingStatusActive . ')';
+            $status = ' (' . __('active') . ')';
         } else {
-            $status = ' (' . $strTrackingStatusNotActive . ')';
+            $status = ' (' . __('not active') . ')';
         }
         if ($entries['table_name'] == $_REQUEST['table']) {
             $s = ' selected="selected"';
@@ -553,7 +553,7 @@ if (PMA_DBI_num_rows($sql_result) > 0) {
     }
     ?>
     </select>
-    <input type="submit" name="show_versions_submit" value="<?php echo $strTrackingShowVersions;?>" />
+    <input type="submit" name="show_versions_submit" value="<?php echo __('Show versions');?>" />
     </form>
 <?php
 }
@@ -583,13 +583,13 @@ if ($last_version > 0) {
     <table id="versions" class="data">
     <thead>
     <tr>
-        <th><?php echo $strDatabase;?></th>
-        <th><?php echo $strTable;?></th>
-        <th><?php echo $strTrackingThVersion;?></th>
-        <th><?php echo $strTrackingThCreated;?></th>
-        <th><?php echo $strTrackingThUpdated;?></th>
-        <th><?php echo $strStatus;?></th>
-        <th><?php echo $strShow;?></th>
+        <th><?php echo __('Database');?></th>
+        <th><?php echo __('Table');?></th>
+        <th><?php echo __('Version');?></th>
+        <th><?php echo __('Created');?></th>
+        <th><?php echo __('Updated');?></th>
+        <th><?php echo __('Status');?></th>
+        <th><?php echo __('Show');?></th>
     </tr>
     </thead>
     <tbody>
@@ -598,29 +598,34 @@ if ($last_version > 0) {
     PMA_DBI_data_seek($sql_result, 0);
     while($version = PMA_DBI_fetch_array($sql_result)) {
         if ($version['tracking_active'] == 1) {
-            $version_status = $strTrackingStatusActive;
+            $version_status = __('active');
         } else {
-            $version_status = $strTrackingStatusNotActive;
+            $version_status = __('not active');
         }
-        if (($version['version'] == $last_version) && ($version_status == $strTrackingStatusNotActive)) {
-            $tracking_active = false;
-        }
-        if (($version['version'] == $last_version) && ($version_status == $strTrackingStatusActive)) {
-            $tracking_active = true;
+        if ($version['version'] == $last_version){
+            if ($version['tracking_active'] == 1) {
+                $tracking_active = true;
+            } else {
+                $tracking_active = false;
+            }
         }
     ?>
-        <tr class="<?php echo $style;?>">
+        <tr class="noclick <?php echo $style;?>">
             <td><?php echo htmlspecialchars($version['db_name']);?></td>
             <td><?php echo htmlspecialchars($version['table_name']);?></td>
-            <td><?php echo $version['version'];?></td>
-            <td><?php echo $version['date_created'];?></td>
-            <td><?php echo $version['date_updated'];?></td>
+            <td><?php echo htmlspecialchars($version['version']);?></td>
+            <td><?php echo htmlspecialchars($version['date_created']);?></td>
+            <td><?php echo htmlspecialchars($version['date_updated']);?></td>
             <td><?php echo $version_status;?></td>
-            <td> <a href="tbl_tracking.php?<?php echo $url_query;?>&amp;report=true&amp;version=<?php echo $version['version'];?>"><?php echo $strTrackingReport;?></a> | <a href="tbl_tracking.php?<?php echo $url_query;?>&amp;snapshot=true&amp;version=<?php echo $version['version'];?>"><?php echo $strTrackingStructureSnapshot;?></a></td>
+            <td> <a href="tbl_tracking.php<?php echo PMA_generate_common_url($url_params + array('report' => 'true', 'version' => $version['version'])
+);?>"><?php echo __('Tracking report');?></a> 
+                | <a href="tbl_tracking.php<?php echo PMA_generate_common_url($url_params + array('snapshot' => 'true', 'version' => $version['version'])
+);?>"><?php echo __('Structure snapshot');?></a>
+            </td>
         </tr>
     <?php
         if ($style == 'even') {
-            $style = 'odd'; 
+            $style = 'odd';
         } else {
             $style = 'even';
         }
@@ -632,9 +637,9 @@ if ($last_version > 0) {
         <div id="div_deactivate_tracking">
         <form method="post" action="tbl_tracking.php?<?php echo $url_query; ?>">
         <fieldset>
-            <legend><?php printf($strTrackingDeactivateTrackingFor, $GLOBALS['db'], $GLOBALS['table']); ?></legend>
+            <legend><?php printf(__('Deactivate tracking for %s.%s'), htmlspecialchars($GLOBALS['db']), htmlspecialchars($GLOBALS['table'])); ?></legend>
             <input type="hidden" name="version" value="<?php echo $last_version; ?>" />
-            <input type="submit" name="submit_deactivate_now" value="<?php echo $strTrackingDeactivateNow; ?>" />
+            <input type="submit" name="submit_deactivate_now" value="<?php echo __('Deactivate now'); ?>" />
         </fieldset>
         </form>
         </div>
@@ -645,9 +650,9 @@ if ($last_version > 0) {
         <div id="div_activate_tracking">
         <form method="post" action="tbl_tracking.php?<?php echo $url_query; ?>">
         <fieldset>
-            <legend><?php printf($strTrackingActivateTrackingFor, $GLOBALS['db'], $GLOBALS['table']); ?></legend>
+            <legend><?php printf(__('Activate tracking for %s.%s'), htmlspecialchars($GLOBALS['db']), htmlspecialchars($GLOBALS['table'])); ?></legend>
             <input type="hidden" name="version" value="<?php echo $last_version; ?>" />
-            <input type="submit" name="submit_activate_now" value="<?php echo $strTrackingActivateNow; ?>" />
+            <input type="submit" name="submit_activate_now" value="<?php echo __('Activate now'); ?>" />
         </fieldset>
         </form>
         </div>
@@ -660,11 +665,11 @@ if ($last_version > 0) {
 <form method="post" action="tbl_tracking.php?<?php echo $url_query; ?>">
 <?php echo PMA_generate_common_hidden_inputs($GLOBALS['db'], $GLOBALS['table']); ?>
 <fieldset>
-    <legend><?php printf($strTrackingCreateVersionOf, ($last_version + 1), $GLOBALS['db'], $GLOBALS['table']); ?></legend>
+    <legend><?php printf(__('Create version %s of %s.%s'), ($last_version + 1), htmlspecialchars($GLOBALS['db']), htmlspecialchars($GLOBALS['table'])); ?></legend>
 
     <input type="hidden" name="version" value="<?php echo ($last_version + 1); ?>" />
 
-    <p><?php echo $strTrackingTrackDDStatements;?></p>
+    <p><?php echo __('Track these data definition statements:');?></p>
     <input type="checkbox" name="alter_table" value="true" checked="checked" /> ALTER TABLE<br/>
     <input type="checkbox" name="rename_table" value="true" checked="checked" /> RENAME TABLE<br/>
     <input type="checkbox" name="create_table" value="true" checked="checked" /> CREATE TABLE<br/>
@@ -672,7 +677,7 @@ if ($last_version > 0) {
     <br/>
     <input type="checkbox" name="create_index" value="true" checked="checked" /> CREATE INDEX<br/>
     <input type="checkbox" name="drop_index" value="true" checked="checked" /> DROP INDEX<br/>
-    <p><?php echo $strTrackingTrackDMStatements;?></p>
+    <p><?php echo __('Track these data manipulation statements:');?></p>
     <input type="checkbox" name="insert" value="true" checked="checked" /> INSERT<br/>
     <input type="checkbox" name="update" value="true" checked="checked" /> UPDATE<br/>
     <input type="checkbox" name="delete" value="true" checked="checked" /> DELETE<br/>
@@ -680,7 +685,7 @@ if ($last_version > 0) {
 
 </fieldset>
 <fieldset class="tblFooters">
-    <input type="submit" name="submit_create_version" value="<?php echo $strTrackingCreateVersion; ?>" />
+    <input type="submit" name="submit_create_version" value="<?php echo __('Create version'); ?>" />
 </fieldset>
 </form>
 </div>
@@ -691,5 +696,5 @@ if ($last_version > 0) {
 /**
  * Displays the footer
  */
-require_once './libraries/footer.inc.php';
+require './libraries/footer.inc.php';
 ?>
