@@ -13,16 +13,16 @@ define('PMA_MINIMUM_COMMON', true);
 /**
  * Gets core libraries and defines some variables
  */
-require_once './libraries/common.inc.php';
+require './libraries/common.inc.php';
 /**
  * ZIP file handler.
  */
-require_once './libraries/zip.lib.php';
+require './libraries/zip.lib.php';
 
 // ini file
 $parameters = array(
     'id'        => 'phpMyAdmin@' . $_SERVER['HTTP_HOST'],
-    'uri'       => $_SESSION['PMA_Config']->get('PmaAbsoluteUri'),
+    'uri'       => $GLOBALS['PMA_Config']->get('PmaAbsoluteUri'),
     'status'    => 'yes',
     'location'  => 'no',
     'sidebar'   => 'no',
